import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { arc, pie, scaleBand, scaleLinear, min, max, format, timeFormat, timeParse } from 'd3';
import { useData } from './useData'
import { AxisBottom } from './AxisBottom'
import { AxisLeft } from './AxisLeft'
import { Marks } from './Marks'

const csvUrl = 'https://gist.githubusercontent.com/HunsingerUK/d19e7c4f3c650d314e8d2400458704cb/raw/c8bd93a3462f8688d00a399388393b9cd84010b7/runs.csv';
const width = 960;
const height = 500;
const margin = { top: 20, right: 20, bottom: 100, left: 100 };
const xAxisLabel = 70;

const App = () => {
  const { data } = useData(csvUrl);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  const xValue = d => d.When;
  const yValue = d => d.Distance;
  
  const dateParse = timeParse("%m/%d/%Y");
  const val = d => timeFormat("%m/%d/%y")(dateParse(d))
  
  
  const xScale = scaleBand()
  	.domain(data.map(xValue))
  	.range([0, innerWidth])
  	.paddingInner(.15);
  
  const yScale = scaleLinear()
  	.domain([0, max(data, yValue)])
  	.range([innerHeight, 0]);
  
  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        <AxisBottom scale={xScale} height={innerHeight} dateFormatter={val} />
        <AxisLeft scale={yScale} width={innerWidth} />
        <text className="axis-label" x={innerWidth /2} y={innerHeight + xAxisLabel} textAnchor="middle" >
          Runs
        </text>
				<Marks data={data} xScale={xScale} yScale={yScale} xValue={xValue} yValue={yValue} height={innerHeight} />
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
